==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_getsample.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}

/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 

/* ==================================================================== */
// 
// sample = setrandvar_getsample ( token , k , i ) 
//   returns the sample input #i=1, where 1<= i<= nx, where nx is the number 
//     of input random variables of the sample #k, where 1<= k<= np, where np is the number of experiments
// sample = setrandvar_getsample ( token , k )
//   returns the sample #k as a matrix with size 1 x (nx), where 1<= k<= np, np is the number of experiments and 
//      nx is the number of input random variables.
// sample = setrandvar_getsample ( token )
//   returns the sampling matrix with size (np) x (nx), where
//      np is the number of experiments and nx is the number of input random variables.
//
int sci_setrandvar_getsample (char *fname)
{
	int m, n;
	int token;
	SetRandomVariable * srv = NULL;
	double * mydata = NULL;
	double *pdblFinalVar = NULL; //SCILAB return Var
	int i, k;
	int nx;
	int np;
	double sample;

	CheckRhs(1,3) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , & token );
	if ( Rhs == 3 ) {
		// sample = setrandvar_getsample ( token , k , i ) 
		nisp_GetOneInteger ( fname , 2 , &k );
		nisp_GetOneInteger ( fname , 3 , &i );
	} else if ( Rhs == 2 ) {
		// sample = setrandvar_getsample ( token , k )
		nisp_GetOneInteger ( fname , 2 , &k );
	}
	nisp_token2Setrandvar ( fname , 1 , token , &srv );
	if ( Rhs == 3 ) {
		// sample = setrandvar_getsample ( token , k , i ) 
		sample = srv->GetSample ( k , i );
		nisp_CreateLhsDouble ( 1 , sample );
	} else if ( Rhs == 2 ) {
		// sample = setrandvar_getsample ( token , k )
		nx = srv->GetDimension();
		m=1;
		n=nx;
		iAllocMatrixOfDouble(Rhs+1, m, n, &pdblFinalVar);
		for(int i=1;i<=nx;i++) {
			pdblFinalVar[i-1] = srv->GetSample(k, i);
		}
		LhsVar(1) = Rhs+1;
	} else if ( Rhs == 1 ) {
		// sample = setrandvar_getsample ( token )
		nx = srv->GetDimension();
		np = srv->GetSize();
		m=np;
		n=nx;
		iAllocMatrixOfDouble(Rhs+1, m, n, &pdblFinalVar);
		for(int i=1;i<=nx;i++) {
			for(int k = 1; k <= np; k++) {
				*(pdblFinalVar + (i-1) * np + (k-1)) = srv->GetSample(k, i);
			}
		}
		LhsVar(1) = Rhs+1;
	}
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_setrandvar_getsample.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}

/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 

/* ==================================================================== */
// 
// sample = setrandvar_getsample ( token , k , i ) 
//   returns the sample input #i=1, where 1<= i<= nx, where nx is the number 
//     of input random variables of the sample #k, where 1<= k<= np, where np is the number of experiments
// sample = setrandvar_getsample ( token , k )
//   returns the sample #k as a matrix with size 1 x (nx), where 1<= k<= np, np is the number of experiments and 
//      nx is the number of input random variables.
// sample = setrandvar_getsample ( token )
//   returns the sampling matrix with size (np) x (nx), where
//      np is the number of experiments and nx is the number of input random variables.
//
int sci_setrandvar_getsample (char *fname)
{
	int m, n;
	int token;
	SetRandomVariable * srv = NULL;
	double * mydata = NULL;
	double *pdblFinalVar = NULL; //SCILAB return Var
	int i, k;
	int nx;
	int np;
	double sample;

	CheckRhs(1,3) ;
	CheckLhs(0,1) ;
	nispgw_gettoken ( fname , 1 , & token );
	if ( Rhs == 3 ) {
		// sample = setrandvar_getsample ( token , k , i ) 
		nispgw_GetOneInteger ( fname , 2 , &k );
		nispgw_GetOneInteger ( fname , 3 , &i );
	} else if ( Rhs == 2 ) {
		// sample = setrandvar_getsample ( token , k )
		nispgw_GetOneInteger ( fname , 2 , &k );
	}
	nispgw_token2Setrandvar ( fname , 1 , token , &srv );
	if ( Rhs == 3 ) {
		// sample = setrandvar_getsample ( token , k , i ) 
		sample = srv->GetSample ( k , i );
		nispgw_CreateLhsDouble ( 1 , sample );
	} else if ( Rhs == 2 ) {
		// sample = setrandvar_getsample ( token , k )
		nx = srv->GetDimension();
		m=1;
		n=nx;
		iAllocMatrixOfDouble(Rhs+1, m, n, &pdblFinalVar);
		for(int i=1;i<=nx;i++) {
			pdblFinalVar[i-1] = srv->GetSample(k, i);
		}
		LhsVar(1) = Rhs+1;
	} else if ( Rhs == 1 ) {
		// sample = setrandvar_getsample ( token )
		nx = srv->GetDimension();
		np = srv->GetSize();
		m=np;
		n=nx;
		iAllocMatrixOfDouble(Rhs+1, m, n, &pdblFinalVar);
		for(int i=1;i<=nx;i++) {
			for(int k = 1; k <= np; k++) {
				*(pdblFinalVar + (i-1) * np + (k-1)) = srv->GetSample(k, i);
			}
		}
		LhsVar(1) = Rhs+1;
	}
	return 0;
}
/* ==================================================================== */
